geowatch.tasks.cold package
===========================

Submodules
----------

.. toctree::
   :maxdepth: 4

   geowatch.tasks.cold.assemble_cold_result_kwcoco
   geowatch.tasks.cold.export_change_map
   geowatch.tasks.cold.export_cold_result_kwcoco
   geowatch.tasks.cold.predict
   geowatch.tasks.cold.prepare_ard
   geowatch.tasks.cold.prepare_kwcoco
   geowatch.tasks.cold.tile_processing
   geowatch.tasks.cold.tile_processing_kwcoco
   geowatch.tasks.cold.transfer_features
   geowatch.tasks.cold.writing_kwcoco

Module contents
---------------

.. automodule:: geowatch.tasks.cold
   :members:
   :undoc-members:
   :show-inheritance:
